import { Libp2p, MultiaddrConnection, PrivateKey, PubSub } from "@libp2p/interface";
import { Identify } from "@libp2p/identify";
import { KadDHT } from "@libp2p/kad-dht";
import { Ping } from "@libp2p/ping";
import { GossipsubEvents } from "@chainsafe/libp2p-gossipsub";
export { GossipSub } from "@chainsafe/libp2p-gossipsub";
import type { Registry } from "prom-client";
import { Multiaddr } from "@multiformats/multiaddr";
import { RendezvousClient } from "@canvas-js/libp2p-rendezvous/client";
import { AbstractGossipLog } from "@canvas-js/gossiplog";
import { GossipLogService } from "./service.js";
export interface NetworkConfig {
    /** start libp2p on initialization (default: true) */
    start?: boolean;
    privateKey?: PrivateKey;
    /** array of local WebSocket multiaddrs, e.g. "/ip4/127.0.0.1/tcp/3000/ws" */
    listen?: string[];
    /** array of public WebSocket multiaddrs, e.g. "/dns4/myapp.com/tcp/443/wss" */
    announce?: string[];
    bootstrapList?: string[];
    denyDialMultiaddr?(multiaddr: Multiaddr): Promise<boolean> | boolean;
    denyInboundConnection?(maConn: MultiaddrConnection): Promise<boolean> | boolean;
    maxConnections?: number;
    registry?: Registry;
}
export type ServiceMap<Payload> = {
    identify: Identify;
    ping: Ping;
    pubsub: PubSub<GossipsubEvents>;
    gossipLog: GossipLogService<Payload>;
    dht: KadDHT;
    rendezvous: RendezvousClient;
};
export declare function getLibp2p<Payload>(gossipLog: AbstractGossipLog<Payload>, config: NetworkConfig): Promise<Libp2p<ServiceMap<Payload>>>;
