import * as cbor from "@ipld/dag-cbor";
import { Event } from "@canvas-js/gossiplog/protocols/events";
import { sha256 } from "@noble/hashes/sha256";
import { bytesToHex } from "@noble/hashes/utils";
export const cborNull = cbor.encode(null);
// eslint-disable-next-line no-useless-escape
export const gossiplogTopicPattern = /^[a-zA-Z0-9\.\-]+(\#[a-zA-Z0-9]+)?$/;
export function hashSnapshot(snapshot) {
    const hash = sha256(cbor.encode(snapshot));
    return bytesToHex(hash).slice(0, 16);
}
/** Logarithmic clock decay */
export function* getAncestorClocks(clock) {
    let i = 0;
    while (true) {
        const ancestor = clock - (1 << i++);
        if (ancestor > 0) {
            yield ancestor;
        }
        else {
            break;
        }
    }
}
export const getSyncProtocol = (topic) => `/canvas/v1/${topic}/sync`;
export const getPushProtocol = (topic) => `/canvas/v1/${topic}/push`;
export async function* chunk(iter) {
    for await (const item of iter) {
        yield item.subarray();
    }
}
export async function* decodeEvents(source) {
    for await (const msg of source) {
        const event = Event.decode(msg.subarray());
        yield event;
    }
}
export async function* encodeEvents(source) {
    for await (const event of source) {
        yield Event.encode(event);
    }
}
